==> fandomanime-0.0.2.tar.gz: fandomanime-0.0.2/README.md <==
# Overview
Written to scrape clean anime summaries from https://www.fandom.com/

###  Getting it

To download animefandom, either fork this github repo or simply use Pypi via pip.
```sh
$ pip install animefandom-Matt711
```

### Using it

First, 
```Python
from animefandom import AnimeFandom
```
Create an animefandom object

```Python
afObject = AnimeFandom("https://naruto.fandom.com/wiki/Konohamaru!!")
```
Now get the summary,
```Python
print(afObject.getSummary()
```

License
----

MIT License

MIT License

Copyright (c) 2020 Matthew Murray

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> fandomanime-0.0.3.tar.gz: fandomanime-0.0.3/README.md <==
# Overview
Written to scrape clean anime summaries from https://www.fandom.com/

###  Getting it

To download animefandom, either fork this github repo or simply use Pypi via pip.
```sh
$ pip install fandomanime
```

### Using it

First, 
```Python
import fandomanime as fa
```
Create an fandomanime object

```Python
faObject = fa.AnimeFandom("https://naruto.fandom.com/wiki/Konohamaru!!")
```
Now get the summary,
```Python
print(faObject.getSummary())
```

License
----

MIT License

MIT License

Copyright (c) 2020 Matthew Murray

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
